@@ -15,10 +15,13 @@ Options:
   --insecure    Allow outside connections (insecure!). Not with --debug.
 
 """
+from bw2data import config
 from bw2ui.web import bw2webapp
 from bw2ui.utils import clean_jobs_directory
 from docopt import docopt
-from werkzeug.serving import run_simple
+# from werkzeug.serving import run_simple
+import logging
+import os
 import threading
 import webbrowser
 
@@ -29,6 +32,7 @@ if __name__ == "__main__":
     args = docopt(__doc__, version='Brightway2 Web UI 0.1')
     port = int(args.get("--port", False) or 5000)  # + random.randint(0, 999))
     host = "0.0.0.0" if args.get("--insecure", False) else "localhost"
+    debug = args["--debug"]
 
     if not args["--nobrowser"]:
         url = "http://127.0.0.1:{}".format(port)
@@ -38,7 +42,24 @@ if __name__ == "__main__":
         "processes": args.get("<processes>", 0) or 3,
     }
 
-    if args["--debug"]:
-        bw2webapp.run(debug=False)
-    else:
-        run_simple(host, port, bw2webapp, use_evalex=True, **kwargs)
+    if not debug:
+        handler = logging.handlers.RotatingFileHandler(
+            os.path.join(config.dir, 'logs', "web-ui-error.log"),
+            maxBytes=50000, encoding='utf-8', backupCount=5)
+        handler.setLevel(logging.WARNING)
+        handler.setFormatter(logging.Formatter('''
+Message type:       %(levelname)s
+Location:           %(pathname)s:%(lineno)d
+Module:             %(module)s
+Function:           %(funcName)s
+Time:               %(asctime)s
+Message:
+%(message)s
+
+'''))
+
+        bw2webapp.logger.addHandler(handler)
+
+    bw2webapp.run(debug=debug)
+    # run_simple disabled because multiple workers cause cache conflicts...
+    # run_simple(host, port, bw2webapp, use_evalex=True, **kwargs)
